
# Slot: develops from




URI: [biolink:develops_from](https://w3id.org/biolink/vocab/develops_from)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | BTO:develops_from |
|  | | DDANAT:develops_from |
|  | | FMA:develops_from |
|  | | RO:0002202 |
| **Close Mappings:** | | RO:0002203 |
|  | | FMA:develops_into |
| **Narrow Mappings:** | | RO:0002207 |
|  | | RO:0002225 |
|  | | RO:0002226 |

